@@ -67,10 +67,10 @@ def purge_directories(directories, max_days):
                 os.remove(filepath)
 
 
-def write_root_to_xml_files(root, path):
+def write_root_to_xml_files(root, path, subfolder=None):
     tree = ET.ElementTree(root)
     tree.write(path)
-    install_content(path)
+    install_content(path, subfolder)
 
 
 def xml_to_root(path):
